@@ -49,14 +49,22 @@ if (typeof(window['yafowil']) == "undefined") yafowil = {};
                     row += '<td class="actions">';
                     row +=   '<div class="array_actions">';
                     if (css.indexOf('array-add') > -1) {
-                        row += '<a class="array_row_add" href="#">&nbsp;</a>';
+                        row += '<a class="array_row_add" href="#">';
+                        row +=   '<i class="icon-plus-sign">&nbsp;</i>';
+                        row += '</a>';
                     }
                     if (css.indexOf('array-remove') > -1) {
-                        row += '<a class="array_row_remove" href="#">&nbsp</a>';
+                        row += '<a class="array_row_remove" href="#">';
+                        row +=   '<i class="icon-minus-sign">&nbsp;</i>';
+                        row += '</a>';
                     }
                     if (css.indexOf('array-sort') > -1) {
-                        row += '<a class="array_row_up" href="#">&nbsp</a>';
-                        row += '<a class="array_row_down" href="#">&nbsp</a>';
+                        row += '<a class="array_row_up" href="#">';
+                        row +=   '<i class="icon-circle-arrow-up">&nbsp;</i>';
+                        row += '</a>';
+                        row += '<a class="array_row_down" href="#">';
+                        row +=   '<i class="icon-circle-arrow-down">&nbsp;</i>';
+                        row += '</a>';
                     }
                     row +=   '</div>';
                     row += '</td>';
